﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using C1.Win.C1FlexGrid;

namespace Win_Flex_Hyperlink
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            // Styles for Links which are yet to be visited
            CellStyle cs = _flex.Styles.Add("NewLink");
            cs.Font = new Font(_flex.Font, FontStyle.Underline);
            cs.ForeColor = Color.Blue;
            cs.TextAlign = TextAlignEnum.RightCenter;

            // Styles for Links which are visited
            cs = _flex.Styles.Add("OldLink");
            cs.Font = new Font(_flex.Font, FontStyle.Underline);
            cs.ForeColor = Color.Purple;
            cs.TextAlign = TextAlignEnum.RightCenter;

            C1FlexGrid grid = this._flex;
            grid.VisualStyle = VisualStyle.System;
            grid.Styles.Normal.WordWrap = true;
            grid.Cols.Count = 3;
            grid.Rows.Count = 4;
            grid.Rows.Fixed = 1;
            grid.Styles.Fixed.TextAlign = TextAlignEnum.CenterCenter;

            grid.MouseMove += new MouseEventHandler(_flex_MouseMove);
            grid.MouseDown += new MouseEventHandler(_flex_MouseDown);
            grid.DrawMode = DrawModeEnum.OwnerDraw;
            grid.OwnerDrawCell += new OwnerDrawCellEventHandler(_flex_OwnerDrawCell);

            CellRange rng;
            rng = grid.GetCellRange(0, 1);
            rng.Data = "Web Links";

            rng = grid.GetCellRange(1, 1);
            rng.UserData = new HyperLinkData() { Visited = false, url = "http://www.google.com"};
            rng.Data = "Google";

            rng = grid.GetCellRange(2, 1);
            rng.UserData = new HyperLinkData() { Visited = false, url = "http://msdn.microsoft.com/" };
            rng.Data = "MSDN";

            rng = grid.GetCellRange(3, 1);
            rng.UserData = new HyperLinkData() { Visited = false, url = "http://www.youtube.com" };
            rng.Data = "Youtube";
        }


        private void _flex_MouseMove(object sender, System.Windows.Forms.MouseEventArgs e)
        {
            HitTestInfo ht = _flex.HitTest(e.X, e.Y);
            bool hand = false;
            if (ht.Type == HitTestTypeEnum.Cell && ht.Column == 1)
            {
                CellRange cr = _flex.GetCellRange(ht.Row, ht.Column);
                if (cr.UserData.GetType() == typeof(HyperLinkData))
                {
                    using (Graphics g = _flex.CreateGraphics())
                    {
                        Rectangle rc = _flex.GetCellRect(ht.Row, ht.Column, false);
                        int width = (int)g.MeasureString(cr.DataDisplay, _flex.Font).Width;
                        if (rc.Right - e.X <= width)
                            hand = true;
                    }
                }
            }
            Cursor = (hand) ? Cursors.Hand : Cursors.Default;
        }

        private void _flex_MouseDown(object sender, System.Windows.Forms.MouseEventArgs e)
        {
            if (Cursor == Cursors.Hand)
            {
                HitTestInfo ht = _flex.HitTest(e.X, e.Y);
                if (ht.Type == HitTestTypeEnum.Cell && ht.Column == 1)
                {
                    CellRange cr = _flex.GetCellRange(ht.Row, ht.Column);
                    if (cr.UserData.GetType() == typeof(HyperLinkData))
                    {
                        System.Diagnostics.Process.Start((cr.UserData as HyperLinkData).url);
                        (cr.UserData as HyperLinkData).Visited = true;
                    }
                }
            }
        }

        private void _flex_OwnerDrawCell(object sender, C1.Win.C1FlexGrid.OwnerDrawCellEventArgs e)
        {
            if (e.Col == 1 && e.Row >= _flex.Rows.Fixed)
            {
                CellRange cr = _flex.GetCellRange(e.Row, e.Col);
                if (cr.UserData.GetType() == typeof(HyperLinkData))
                {
                    if ((cr.UserData as HyperLinkData).Visited == true)
                        e.Style = _flex.Styles["OldLink"];
                    else
                        e.Style = _flex.Styles["NewLink"];
                }
            }
        }
    }
    public class HyperLinkData
    {
        public bool Visited { get; set; }
        public string url { get; set; }
    }
}
